Tools
=====

Utilities complementing the core functionalities. Includes post-processing and visualizations.


HDF interface
-------------

.. automodule:: tomotok.core.tools.hdf
    :members:
    :undoc-members:
    :noindex:


Post Processing
---------------
Processing of tomography results. Planned to be expanded. Currently only power computation implemented.

.. automodule:: tomotok.core.tools.postproc
    :members: compute_power
    :noindex:


Projection space
----------------
Transforms lines of sights into projections space parametrization.

.. automodule:: tomotok.core.tools.projection
    :members: projection_space
    :undoc-members:
    :noindex:
